==> igniteui-webcomponents-core-3.5.0.tgz: package/esm2015/lib/WebRowSelectorTemplateContextDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { WebRowSelectorTemplateDetailsDescriptionMetadata } from "./WebRowSelectorTemplateDetailsDescriptionMetadata";
import { WebRowSelectorTemplateContextDescription } from "./WebRowSelectorTemplateContextDescription";
/**
 * @hidden
 */
export let WebRowSelectorTemplateContextDescriptionMetadata = /*@__PURE__*/ (() => {
    class WebRowSelectorTemplateContextDescriptionMetadata extends Base {
        static b(a) {
            if (WebRowSelectorTemplateContextDescriptionMetadata.a == null) {
                WebRowSelectorTemplateContextDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                WebRowSelectorTemplateContextDescriptionMetadata.c(WebRowSelectorTemplateContextDescriptionMetadata.a);
            }
            if (a.j(WebRowSelectorTemplateContextDescriptionMetadata.a)) {
                return;
            }
            a.y(WebRowSelectorTemplateContextDescriptionMetadata.a);
            WebRowSelectorTemplateDetailsDescriptionMetadata.d(a);
        }
        static c(a) {
            a.item("__qualifiedNameTS", "String:RowSelectorTemplateContext");
            a.item("__packageNameWC", "String:grids");
            a.item("__isPlainObject", "Boolean");
            a.item("Implicit", "ExportedType:WebRowSelectorTemplateDetails");
        }
        static d(a) {
            WebRowSelectorTemplateContextDescriptionMetadata.b(a);
            a.aa("WebRowSelectorTemplateContext", () => new WebRowSelectorTemplateContextDescription());
            a.z("WebRowSelectorTemplateContext", WebRowSelectorTemplateContextDescriptionMetadata.a);
        }
    }
    WebRowSelectorTemplateContextDescriptionMetadata.$t = /*@__PURE__*/ markType(WebRowSelectorTemplateContextDescriptionMetadata, 'WebRowSelectorTemplateContextDescriptionMetadata');
    WebRowSelectorTemplateContextDescriptionMetadata.a = null;
    return WebRowSelectorTemplateContextDescriptionMetadata;
})();

==> igniteui-webcomponents-core-4.2.5.tgz: package/esm2015/lib/WebRowSelectorTemplateContextDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { WebRowSelectorTemplateDetailsDescriptionMetadata } from "./WebRowSelectorTemplateDetailsDescriptionMetadata";
import { WebRowSelectorTemplateContextDescription } from "./WebRowSelectorTemplateContextDescription";
/**
 * @hidden
 */
export let WebRowSelectorTemplateContextDescriptionMetadata = /*@__PURE__*/ (() => {
    class WebRowSelectorTemplateContextDescriptionMetadata extends Base {
        static b(a) {
            if (WebRowSelectorTemplateContextDescriptionMetadata.a == null) {
                WebRowSelectorTemplateContextDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                WebRowSelectorTemplateContextDescriptionMetadata.c(WebRowSelectorTemplateContextDescriptionMetadata.a);
            }
            if (a.k(WebRowSelectorTemplateContextDescriptionMetadata.a)) {
                return;
            }
            a.aa(WebRowSelectorTemplateContextDescriptionMetadata.a);
            WebRowSelectorTemplateDetailsDescriptionMetadata.d(a);
        }
        static c(a) {
            a.item("__qualifiedNameTS", "String:RowSelectorTemplateContext");
            a.item("__packageNameWC", "String:grids");
            a.item("__skipModuleRegisterWebComponents", "Boolean");
            a.item("__importOverrideWebComponents", "String:igniteui-webcomponents-grids/grids/combined");
            a.item("__importTypesWebComponents", "String:igniteui-webcomponents-grids/grids");
            a.item("__isPlainObject", "Boolean");
            a.item("__skipSuffix", "Boolean");
            a.item("Implicit", "ExportedType:WebRowSelectorTemplateDetails");
        }
        static d(a) {
            WebRowSelectorTemplateContextDescriptionMetadata.b(a);
            a.ac("WebRowSelectorTemplateContext", () => new WebRowSelectorTemplateContextDescription());
            a.ab("WebRowSelectorTemplateContext", WebRowSelectorTemplateContextDescriptionMetadata.a);
        }
    }
    WebRowSelectorTemplateContextDescriptionMetadata.$t = /*@__PURE__*/ markType(WebRowSelectorTemplateContextDescriptionMetadata, 'WebRowSelectorTemplateContextDescriptionMetadata');
    WebRowSelectorTemplateContextDescriptionMetadata.a = null;
    return WebRowSelectorTemplateContextDescriptionMetadata;
})();
